@@ -224,6 +224,8 @@ class AnsiEscapeCodes:
     __dim_as_gray = os.environ.get('GIT_MACHETE_DIM_AS_GRAY') == 'true'
 
     ENDC = '\033[0m'
+    ENDC_UNDERLINE = '\033[24m'
+    ENDC_BOLD_DIM = '\033[22m'
     BOLD = '\033[1m'
     DIM = '\033[38;2;128;128;128m' if __dim_as_gray else '\033[2m'
     # Let's fall back to cyan on 8-color terminals
@@ -237,16 +239,16 @@ class AnsiEscapeCodes:
 
 
 def bold(s: str) -> str:
-    return s if ascii_only or not s else AnsiEscapeCodes.BOLD + s + AnsiEscapeCodes.ENDC
+    return s if ascii_only or not s else AnsiEscapeCodes.BOLD + s + AnsiEscapeCodes.ENDC_BOLD_DIM
 
 
 def dim(s: str) -> str:
-    return s if ascii_only or not s else AnsiEscapeCodes.DIM + s + AnsiEscapeCodes.ENDC
+    return s if ascii_only or not s else AnsiEscapeCodes.DIM + s + AnsiEscapeCodes.ENDC_BOLD_DIM
 
 
 def underline(s: str, star_if_ascii_only: bool = False) -> str:
     if s and not ascii_only:
-        return AnsiEscapeCodes.UNDERLINE + s + AnsiEscapeCodes.ENDC
+        return AnsiEscapeCodes.UNDERLINE + s + AnsiEscapeCodes.ENDC_UNDERLINE
     elif s and star_if_ascii_only:
         return s + " *"
     else:
@@ -258,13 +260,14 @@ def colored(s: str, color: str) -> str:
 
 
 fmt_transformations: List[Callable[[str], str]] = [
+    lambda x: re.sub('`(.*?)`', underline(r"\1"), x),
     lambda x: re.sub('<b>(.*?)</b>', bold(r"\1"), x, flags=re.DOTALL),
     lambda x: re.sub('<u>(.*?)</u>', underline(r"\1"), x, flags=re.DOTALL),
     lambda x: re.sub('<dim>(.*?)</dim>', dim(r"\1"), x, flags=re.DOTALL),
     lambda x: re.sub('<red>(.*?)</red>', colored(r"\1", AnsiEscapeCodes.RED), x, flags=re.DOTALL),
     lambda x: re.sub('<yellow>(.*?)</yellow>', colored(r"\1", AnsiEscapeCodes.YELLOW), x, flags=re.DOTALL),
     lambda x: re.sub('<green>(.*?)</green>', colored(r"\1", AnsiEscapeCodes.GREEN), x, flags=re.DOTALL),
-    lambda x: re.sub('`(.*?)`', r"`\1`" if ascii_only else AnsiEscapeCodes.UNDERLINE + r"\1" + AnsiEscapeCodes.ENDC, x),
+    lambda x: re.sub('<orange>(.*?)</orange>', colored(r"\1", AnsiEscapeCodes.ORANGE), x, flags=re.DOTALL)
 ]
 
 
